# [0.9.0] - 2019-04-30

## Changed

The `error_coercer` signature changed from `Callable[[Exception]] -> dict` to `Callable[[Exception], dict] -> dict`.

The main idea of this change is to avoid calling the coerce_value ourselves within our own error_coercer implementation, as this call can be executed by the engine.

Here are 2 examples of a custom error_coercer, the first one with the old way and the second one with the new way.

*Old way*
```python
from myvender import CustomException
from tartiflette.engine import Engine
from tartiflette.resolver.factory import default_error_coercer

def my_custom_error_coercer(exception):
    error = default_error_coercer(exception)

    if isinstance(exception, CustomException):
        error["customfield"] = "blabla"

    return error

engine = Engine(
    # parameters ...
    error_coercer=my_custom_error_coercer
)
```

**New way**
```python
from myvender import CustomException
from tartiflette.engine import Engine
from tartiflette.resolver.factory import default_error_coercer

def my_custom_error_coercer(exception, error):
    if isinstance(exception, CustomException):
        error["customfield"] = "blabla"

    return error

engine = Engine(
    # parameters ...
    error_coercer=my_custom_error_coercer
)
```
